![](https://www.phonexia.com/wp-content/uploads/phonexia-logo-transparent-500px.png)

# Phonexia denoiser client

This module contains client for communication with [denoiser](https://hub.docker.com/repository/docker/phonexia/denoiser/general) developed by [Phonexia](https://phonexia.com).

To use this client you will first need a running instance of any *Phonexia denoiser*. If you don't yet have any running instance, don't hesitate to [contact our sales department](mailto:info@phonexia.com).

You can learn more about the denoiser technology [here](https://docs.cloud.phonexia.com/docs/technologies/denoiser/).

On [this page](https://docs.cloud.phonexia.com/docs/products/speech-platform-4/grpc/api/phonexia/grpc/technologies/denoiser/v1/denoiser.proto), you will find a *gRPC API* reference for *denoiser microservice*.
